# Copyright (C) 2019 Arturs Ontuzans
# 
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTIBILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.

bl_info = {
    "name" : "Unreal Engine 4 Vehicle Rigger",
    "author" : "Arthur",
    "description" : "Helps to rig vehicles for Unreal Engine 4",
    "blender" : (2, 80, 0),
    "version" : (0, 0, 1),
    "location" : "View3D",
    "warning" : "",
    "category" : "Generic"
}

import bpy

from . rig_op import Rig_OT_Operator, Scale_Units_OT_Operator, Upscale_Objects_OT_Operator
from . ui_panel import UI_PT_Rig_Panel, UI_PT_Scene_Setup_Panel

def object_search_poll(self, object):
    return object.type in ['MESH', 'CURVE']

def register():
    bpy.utils.register_class(Rig_OT_Operator)
    bpy.utils.register_class(Scale_Units_OT_Operator)
    bpy.utils.register_class(Upscale_Objects_OT_Operator)
    bpy.utils.register_class(UI_PT_Rig_Panel)
    bpy.utils.register_class(UI_PT_Scene_Setup_Panel)
    bpy.types.Scene.vehicle_base = bpy.props.PointerProperty(type=bpy.types.Object, poll = object_search_poll)
    bpy.types.Scene.wheel_FR = bpy.props.PointerProperty(type=bpy.types.Object, poll = object_search_poll)
    bpy.types.Scene.wheel_FL = bpy.props.PointerProperty(type=bpy.types.Object, poll = object_search_poll)
    bpy.types.Scene.wheel_RR = bpy.props.PointerProperty(type=bpy.types.Object, poll = object_search_poll)
    bpy.types.Scene.wheel_RL = bpy.props.PointerProperty(type=bpy.types.Object, poll = object_search_poll)

def unregister():
    bpy.utils.unregister_class(Rig_OT_Operator)
    bpy.utils.unregister_class(Scale_Units_OT_Operator)
    bpy.utils.unregister_class(Upscale_Objects_OT_Operator)
    bpy.utils.unregister_class(UI_PT_Rig_Panel)
    bpy.utils.unregister_class(UI_PT_Scene_Setup_Panel)
    del bpy.types.Scene.vehicle_base
    del bpy.types.Scene.wheel_FR
    del bpy.types.Scene.wheel_FL
    del bpy.types.Scene.wheel_RR
    del bpy.types.Scene.wheel_RL



